from django.template import Library
register = Library()

def _process_field_attributes(field, attr, process):

    # split attribute name and value from 'attr:value' string
    params = attr.split(':', 1)
    attribute = params[0]
    value = params[1] if len(params) == 2 else ''

    # decorate field.as_widget method with updated attributes
    old_as_widget = field.as_widget
    def as_widget(self, widget=None, attrs=None, only_initial=False):
        attrs = attrs or {}
        process(attrs, attribute, value)
        return old_as_widget(widget, attrs, only_initial)

    bound_method = type(old_as_widget)
    field.as_widget = bound_method(as_widget, field, field.__class__)
    return field

@register.filter('attr')
def set_attr(field, attr):
    def process(attrs, attribute, value):
        attrs[attribute] = value
    return _process_field_attributes(field, attr, process)

@register.filter
def append_attr(field, attr):
    def process(attrs, attribute, value):
        attrs[attribute] = ' '.join([attrs.get(attribute, ''), value])
    return _process_field_attributes(field, attr, process)

@register.filter
def set_data(field, data):
    return set_attr(field, 'data-' + data)

@register.filter
def add_class(field, css_class):
    return append_attr(field, 'class:'+ css_class)



#!/usr/bin/env python
from distutils.core import setup
version='0.1'

setup(
    name = 'django-widget-tweaks',
    version = version,
    author = 'Mikhail Korobov',
    author_email = 'kmike84@gmail.com',
    url = 'http://bitbucket.org/kmike/django-widget-tweaks/',
    download_url = 'http://bitbucket.org/kmike/django-widget-tweaks/get/tip.zip',

    description = 'Tweak the form field rendering in templates, not in python-level form definitions.',
    long_description = open('README.rst').read(),
    license = 'MIT license',
    requires = ['django'],

    packages=['widget_tweaks', 'widget_tweaks.templatetags'],

    classifiers=[
        'Development Status :: 3 - Alpha',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
)
